==> opera-11.00.1156-i486-1sys.tgz: install/doinst.sh <==
if [ -x /usr/bin/update-mime-database ]; then
  /usr/bin/update-mime-database /usr/share/mime &> /dev/null
fi

if [ -x /usr/bin/update-desktop-database ]; then
  /usr/bin/update-desktop-database 1> /dev/null &> /dev/null
fi

if [ -x /usr/bin/gtk-update-icon-cache ]; then
  /usr/bin/gtk-update-icon-cache  -f -q /usr/share/icons/hicolor &> /dev/null
fi

#
( cd usr/share/applications ; rm -rf opera.desktop )
( cd usr/share/applications ; ln -sf opera-browser.desktop opera.desktop )
( cd usr/share/app-install/desktop ; rm -rf opera.desktop )
( cd usr/share/app-install/desktop ; ln -sf ../../applications/opera-browser.desktop opera.desktop )
( cd usr/share/icons/hicolor/24x24/apps ; rm -rf opera-widget.png )
( cd usr/share/icons/hicolor/24x24/apps ; ln -sf ../mimetypes/opera-widget.png opera-widget.png )
( cd usr/share/icons/hicolor/48x48/apps ; rm -rf opera-widget.png )
( cd usr/share/icons/hicolor/48x48/apps ; ln -sf ../mimetypes/opera-widget.png opera-widget.png )
( cd usr/share/icons/hicolor/32x32/apps ; rm -rf opera-widget.png )
( cd usr/share/icons/hicolor/32x32/apps ; ln -sf ../mimetypes/opera-widget.png opera-widget.png )
( cd usr/share/icons/hicolor/16x16/apps ; rm -rf opera-widget.png )
( cd usr/share/icons/hicolor/16x16/apps ; ln -sf ../mimetypes/opera-widget.png opera-widget.png )
( cd usr/share/icons/hicolor/128x128/apps ; rm -rf opera-widget.png )
( cd usr/share/icons/hicolor/128x128/apps ; ln -sf ../mimetypes/opera-widget.png opera-widget.png )
( cd usr/share/icons/hicolor/22x22/apps ; rm -rf opera-widget.png )
( cd usr/share/icons/hicolor/22x22/apps ; ln -sf ../mimetypes/opera-widget.png opera-widget.png )

==> opera-11.10.2092-i486-1sys.tgz: install/doinst.sh <==
if [ -x /usr/bin/update-mime-database ]; then
  /usr/bin/update-mime-database /usr/share/mime &> /dev/null
fi

if [ -x /usr/bin/update-desktop-database ]; then
  /usr/bin/update-desktop-database 1> /dev/null &> /dev/null
fi

if [ -x /usr/bin/gtk-update-icon-cache ]; then
  /usr/bin/gtk-update-icon-cache  -f -q /usr/share/icons/hicolor &> /dev/null
fi

#
( cd usr/share/opera/locale/en ; rm -rf license.txt )
( cd usr/share/opera/locale/en ; ln -sf ../../../doc/opera/LICENSE license.txt )
( cd usr/share/opera/defaults ; rm -rf license.txt )
( cd usr/share/opera/defaults ; ln -sf ../../doc/opera/LICENSE license.txt )
( cd usr/share/icons/hicolor/scalable/apps ; rm -rf opera-widget.svg )
( cd usr/share/icons/hicolor/scalable/apps ; ln -sf ../mimetypes/opera-widget.svg opera-widget.svg )
( cd usr/share/icons/hicolor/24x24/apps ; rm -rf opera-widget.png )
( cd usr/share/icons/hicolor/24x24/apps ; ln -sf ../mimetypes/opera-widget.png opera-widget.png )
( cd usr/share/icons/hicolor/48x48/apps ; rm -rf opera-widget.png )
( cd usr/share/icons/hicolor/48x48/apps ; ln -sf ../mimetypes/opera-widget.png opera-widget.png )
( cd usr/share/icons/hicolor/32x32/apps ; rm -rf opera-widget.png )
( cd usr/share/icons/hicolor/32x32/apps ; ln -sf ../mimetypes/opera-widget.png opera-widget.png )
( cd usr/share/icons/hicolor/16x16/apps ; rm -rf opera-widget.png )
( cd usr/share/icons/hicolor/16x16/apps ; ln -sf ../mimetypes/opera-widget.png opera-widget.png )
( cd usr/share/icons/hicolor/128x128/apps ; rm -rf opera-widget.png )
( cd usr/share/icons/hicolor/128x128/apps ; ln -sf ../mimetypes/opera-widget.png opera-widget.png )
( cd usr/share/icons/hicolor/22x22/apps ; rm -rf opera-widget.png )
( cd usr/share/icons/hicolor/22x22/apps ; ln -sf ../mimetypes/opera-widget.png opera-widget.png )
